A crate for working with old 8-bit string formats
Modules
- config_
data - Embedded config data
- error
- Error types for working with 8-bit strings
- petscii
- PETSCII string library
Structs
- Config
- Configuration format
- System
Config - An individual system config Contains character set mappings
Statics
- CONFIG
- The global configuration settings This is used by default if a custom configuration isn’t used when creating a string.
Traits
- Configuration
- Trait that defines a set of methods that allow loading and unloading configuration data