pub struct ScreenCodeValue {
pub set: u8,
pub value: u8,
}Expand description
A Commodore screen code value and the screen set it is in
The configuration file uses a two-element tuple or list to store the set and value fields. The Serde and Serde JSON serializer automatically support deserializing from a tuple into a struct. This may be confusing so this note is here to let people know.
Fields
set: u8The screen set this code is in
value: u8The screen code value