pub struct Config {
pub version: String,
pub petscii: SystemConfig,
}Expand description
Configuration format
Fields
version: StringVersion of the configuration root
petscii: SystemConfigA mapping for PETSCII systems TODO: Remove this, individual modules should create their own keys, in an approved namespace like good little modules.