pub struct SystemConfig {
pub version: String,
pub character_set_map: PetsciiConfig,
}Expand description
An individual system config Contains character set mappings
Fields
version: StringVersion of this system
character_set_map: PetsciiConfigcharacter_set_map contains the actual mapping from 8-bit characters to Unicode characters and vice-versa
Some “legacy computing” forbidden band crates like the Commodore (CBM) PETSCII crate also have intermediate maps and tables. In the case of CBM there is a set of “screen code” tables that hold information about the in-memory values of characters on the screen.
TODO: I want to get dynamic loading and unloading of modules working. It will require some refactoring with dyn traits and serialization / deserialization to make sure everything works.